@@ -14,7 +14,7 @@ class ftpUtil:
     __username_stud ="student"
     __password_stud ="student"
     __remotedir_media = "media/"
-    __remotedir_stud = "send/"
+    __remotedir_stud = "student/"
     __url_head="https://home.hddly.cn:8443/stud/"
     __mutil= mysqlUtil()
 
