@@ -182,7 +182,7 @@ class mysqlUtil:
         return item
 
     def escape(self,content) :
-        if (content and len(str(content).strip()))>0 :
+        if content and (len(content)>0) and (len(str(content).strip())>0) :
             content = content.replace("\\\\", "\\\\\\\\");
             content = content.replace("_", "\\\\_");
             content = content.replace("%", "\\\\%");
